/* Distributed under the terms of GPLv3 or later. See COPYING for details. */

/*! \file logging.cpp
 *
 * \brief Implementation of the logging system.
 */
#include <cstdio>
#include <string>

#ifndef INCLUDE_LOGGING_H_
#include "../include/logging.h"
#endif

using namespace std;

Logger::Logger(int threshold, FILE *logging_output, FILE *error_output) {
  last_message = "";
  log_threshold = threshold;
  log_output = logging_output;
  err_output = error_output;
  repetitions = 0;
}

void Logger::err(std::string message) {
  fprintf(err_output, "%s", message.c_str());
}

void Logger::flush(int level) {
  string summary = "\"" + last_message + "\" issued " + to_string(repetitions);
  if (repetitions == 1) summary += " time.\n";
  else summary += " times.\n";
  if (level == LOG_ERRO) err(summary);
  else {
    if (level >= log_threshold) fprintf(log_output, "%s", summary.c_str());
  }
  repetitions = 0;
}

void Logger::log(std::string message, int level) {
  if (level == LOG_ERRO) err(message);
  else {
    if (level >= log_threshold) fprintf(log_output, "%s", message.c_str());
  }
}

void Logger::push(std::string message) {
  if (repetitions > 0) {
    if (message.compare(last_message) != 0) {
      flush(LOG_DEBG);
    }
  }
  log(message, LOG_DEBG);
  last_message = message;
  repetitions++;
}
